@@ -46,7 +46,7 @@ class ChannelsList(MyTreeView):
     headers = {
         Columns.SHORT_CHANID: _('Short Channel ID'),
         Columns.NODE_ALIAS: _('Node alias'),
-        Columns.FEATURES: _(''),
+        Columns.FEATURES: "",
         Columns.CAPACITY: _('Capacity'),
         Columns.LOCAL_BALANCE: _('Can send'),
         Columns.REMOTE_BALANCE: _('Can receive'),
@@ -62,8 +62,7 @@ class ChannelsList(MyTreeView):
     _default_item_bg_brush = None  # type: Optional[QBrush]
 
     def __init__(self, parent):
-        super().__init__(parent, self.create_menu, stretch_column=self.Columns.NODE_ALIAS,
-                         editable_columns=[])
+        super().__init__(parent, self.create_menu, stretch_column=self.Columns.NODE_ALIAS)
         self.setModel(QtGui.QStandardItemModel(self))
         self.setSelectionMode(QAbstractItemView.ExtendedSelection)
         self.main_window = parent
@@ -193,11 +192,7 @@ class ChannelsList(MyTreeView):
         if self.lnworker.channel_db or self.lnworker.is_trampoline_peer(chan.node_id):
             chan.set_frozen_for_sending(b)
         else:
-            msg = ' '.join([
-                _("Trampoline routing is enabled, but this channel is with a non-trampoline node."),
-                _("This channel may still be used for receiving, but it is frozen for sending."),
-                _("If you want to keep using this channel, you need to disable trampoline routing in your preferences."),
-            ])
+            msg = messages.MSG_NON_TRAMPOLINE_CHANNEL_FROZEN_WITHOUT_GOSSIP
             self.main_window.show_warning(msg, title=_('Channel is frozen for sending'))
 
     def create_menu(self, position):
@@ -237,7 +232,7 @@ class ChannelsList(MyTreeView):
             channel_id.hex(), title=_("Long Channel ID")))
         if not chan.is_closed():
             if not chan.is_frozen_for_sending():
-                menu.addAction(_("Freeze (for sending)"), lambda: self.freeze_channel_for_sending(chan, True))
+                menu.addAction(_("Freeze (for sending)"), lambda: self.freeze_channel_for_sending(chan, True))  #
             else:
                 menu.addAction(_("Unfreeze (for sending)"), lambda: self.freeze_channel_for_sending(chan, False))
             if not chan.is_frozen_for_receiving():
