@@ -5,8 +5,10 @@ import copy
 from PyQt5.QtCore import Qt, pyqtSignal
 from PyQt5.QtWidgets import QPushButton, QLabel, QVBoxLayout, QWidget, QGridLayout
 
-from electrum.gui.qt.util import WindowModalDialog, CloseButton, get_parent_main_window, Buttons
+from electrum.gui.qt.util import (WindowModalDialog, CloseButton, Buttons, getOpenFileName,
+                                  getSaveFileName)
 from electrum.gui.qt.transaction_dialog import TxDialog
+from electrum.gui.qt.main_window import ElectrumWindow
 
 from electrum.i18n import _
 from electrum.plugin import hook
@@ -63,8 +65,13 @@ class Plugin(ColdcardPlugin, QtPluginBase):
 
         basename = wallet.basename().rsplit('.', 1)[0]        # trim .json
         name = f'{basename}-cc-export.txt'.replace(' ', '-')
-        fileName = main_window.getSaveFileName(_("Select where to save the setup file"),
-                                                        name, "*.txt")
+        fileName = getSaveFileName(
+            parent=main_window,
+            title=_("Select where to save the setup file"),
+            filename=name,
+            filter="*.txt",
+            config=self.config,
+        )
         if fileName:
             with open(fileName, "wt") as f:
                 ColdcardPlugin.export_ms_wallet(wallet, f, basename)
@@ -92,7 +99,7 @@ class Coldcard_Handler(QtHandlerBase):
 
 class CKCCSettingsDialog(WindowModalDialog):
 
-    def __init__(self, window, plugin, keystore):
+    def __init__(self, window: ElectrumWindow, plugin, keystore):
         title = _("{} Settings").format(plugin.device)
         super(CKCCSettingsDialog, self).__init__(window, title)
         self.setMaximumWidth(540)
@@ -104,6 +111,8 @@ class CKCCSettingsDialog(WindowModalDialog):
         #handler = keystore.handler
         self.thread = thread = keystore.thread
         self.keystore = keystore
+        assert isinstance(window, ElectrumWindow), f"{type(window)}"
+        self.window = window
 
         def connect_and_doit():
             # Attempt connection to device, or raise.
@@ -127,7 +136,7 @@ class CKCCSettingsDialog(WindowModalDialog):
 <br><a href="https://coldcardwallet.com">coldcardwallet.com</a>''')
         title.setTextInteractionFlags(Qt.LinksAccessibleByMouse)
 
-        grid.addWidget(title , 0,0, 1,2, Qt.AlignHCenter)
+        grid.addWidget(title, 0,0, 1,2, Qt.AlignHCenter)
         y = 3
 
         rows = [
@@ -188,10 +197,14 @@ class CKCCSettingsDialog(WindowModalDialog):
 
     def start_upgrade(self, client):
         # ask for a filename (must have already downloaded it)
-        mw = get_parent_main_window(self)
         dev = client.dev
 
-        fileName = mw.getOpenFileName("Select upgraded firmware file", "*.dfu")
+        fileName = getOpenFileName(
+            parent=self,
+            title="Select upgraded firmware file",
+            filter="*.dfu",
+            config=self.window.config,
+        )
         if not fileName:
             return
 
@@ -217,7 +230,7 @@ class CKCCSettingsDialog(WindowModalDialog):
             if magic != FW_HEADER_MAGIC:
                 raise ValueError("Bad magic")
         except Exception as exc:
-            mw.show_error("Does not appear to be a Coldcard firmware file.\n\n%s" % exc)
+            self.window.show_error("Does not appear to be a Coldcard firmware file.\n\n%s" % exc)
             return
 
         # TODO: 
@@ -225,7 +238,7 @@ class CKCCSettingsDialog(WindowModalDialog):
         # - warn them about the reboot?
         # - length checks
         # - add progress local bar
-        mw.show_message("Ready to Upgrade.\n\nBe patient. Unit will reboot itself when complete.")
+        self.window.show_message("Ready to Upgrade.\n\nBe patient. Unit will reboot itself when complete.")
 
         def doit():
             dlen, _ = dev.upload_file(firmware, verify=True)
